import { Component, OnInit } from '@angular/core';
import { MatDialogRef, MatSnackBar } from '@angular/material';
import { DarsApiService } from '../services/api.service';
import { DegreeProgram } from '../models/degree-program';
import { StudentDegreeProgram } from '../models/student-degree-program';
import {
  FormBuilder,
  FormGroup,
  FormControl,
  Validators,
  FormArray,
  AbstractControl,
} from '@angular/forms';

@Component({
  selector: 'cse-new-audit-options',
  templateUrl: './new-audit-options.component.html',
  styleUrls: ['./new-audit-options.component.scss'],
})
export class NewAuditOptionsComponent implements OnInit {
  public newAuditForm: FormGroup;
  public degreeProgram: DegreeProgram;
  public degreePrograms: any;
  public programOfStudy: string;
  public studentDegreeProgram: StudentDegreeProgram[];
  public DARSprograms: any;
  public honorsOptions: any;

  get formArray(): AbstractControl | null {
    return this.newAuditForm.get('formArray');
  }

  constructor(
    private fb: FormBuilder,
    private dialogRef: MatDialogRef<NewAuditOptionsComponent>,
    private snackBar: MatSnackBar,
    private api: DarsApiService,
  ) {}

  ngOnInit() {
    this.api.getStaticData().subscribe(degreePrograms => {
      this.degreePrograms = degreePrograms;
      this.honorsOptions = [];
      this.DARSprograms = [];
      for (var school in this.degreePrograms) {
        // Get program of study
        this.programOfStudy = this.degreePrograms[
          school
        ].darsInstitutionCodeDescription;
        // Get honors options
        if (this.degreePrograms[school].hasOwnProperty('honorsOptions')) {
          this.honorsOptions.push(...this.degreePrograms[school].honorsOptions);
        }
        // Get DARS programs
        if (this.degreePrograms[school].hasOwnProperty('programs')) {
          this.DARSprograms.push(...this.degreePrograms[school].programs);
        }
      }
    });

    this.newAuditForm = this.fb.group({
      formArray: this.fb.array([
        this.fb.group({
          auditType: new FormControl('declaredMajorAudit'),
        }),
        this.fb.group({
          darsDegreeProgram: new FormControl(''),
          darsInstitution: new FormControl(''),
          darsInstitutionProgram: new FormControl(''),
        }),
        this.fb.group({
          honors: new FormControl(''),
          includeCoursesFrom: new FormControl(''),
          runAgainst: new FormControl(''),
        }),
        this.fb.group({
          credits: new FormControl(''),
        }),
      ]),
    });
  }

  public runDARSAudit() {
    const {
      auditType,
      programOfStudy,
      academicProgram,
      honors,
      includeCoursesFrom,
      runAgainst,
      credits,
    } = this.newAuditForm.value;

    this.dialogRef.close();
    this.snackBar.open(
      'Audit in progress. You will be notified when the audit is ready to be viewed.',
    );
  }
}
